==> ejc-zdsstore-impl-3.0.0-20240128.053759-153-sources.jar: com/ejianc/business/zdsstore/bean/ReturnGoodsDetailEntity.java <==
package com.ejianc.business.zdsstore.bean;

import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 材料退货明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_store_return_goods_detail")
public class ReturnGoodsDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="store_id")
    private Long storeId; // 仓库id
    @TableField(value="store_name")
    private String storeName; // 仓库名称
    @TableField(value="outstore_id")
    private Long outstoreId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value = "material_type_code")
    private String materialTypeCode; //物资分类编码
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value = "material_code")
    private String materialCode; //物资编码
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit_name")
    private String materialUnitName; // 物资计量单位
    @TableField(value="instore_num")
    private BigDecimal instoreNum; // 入库数量
    @TableField(value="userable_num")
    private BigDecimal userableNum; // 剩余可用数量
    @TableField(value="return_num")
    private BigDecimal returnNum; // 退货数量
    @TableField(value="contract_price")
    private BigDecimal contractPrice; // 合同单价
    @TableField(value="return_price")
    private BigDecimal returnPrice; // 退货单价
    @TableField(value="return_tax_price")
    private BigDecimal returnTaxPrice; // 退货单价(含税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额(含税)
    @TableField(value="tax")
    private BigDecimal tax; //税额
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value = "detail_mny_disparity")
    private BigDecimal detailMnyDisparity; //退货差额
    @TableField(value = "detail_tax_mny_disparity")
    private BigDecimal detailTaxMnyDisparity; //退货差额
    @TableField(value = "brand_id")
    private Long brandId; //品牌Id
    @TableField(value = "brand_name")
    private String brandName; //品牌名称
    @TableField(value = "product_code")
    private String productCode; //产品代码

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public BigDecimal getDetailMnyDisparity() {
        return detailMnyDisparity;
    }

    public void setDetailMnyDisparity(BigDecimal detailMnyDisparity) {
        this.detailMnyDisparity = detailMnyDisparity;
    }

    public BigDecimal getDetailTaxMnyDisparity() {
        return detailTaxMnyDisparity;
    }

    public void setDetailTaxMnyDisparity(BigDecimal detailTaxMnyDisparity) {
        this.detailTaxMnyDisparity = detailTaxMnyDisparity;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getOutstoreId() {
        return outstoreId;
    }

    public void setOutstoreId(Long outstoreId) {
        this.outstoreId = outstoreId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getInstoreNum() {
        return instoreNum;
    }

    public void setInstoreNum(BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    public BigDecimal getUserableNum() {
        return userableNum;
    }

    public void setUserableNum(BigDecimal userableNum) {
        this.userableNum = userableNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    public BigDecimal getReturnPrice() {
        return returnPrice;
    }

    public void setReturnPrice(BigDecimal returnPrice) {
        this.returnPrice = returnPrice;
    }
    public BigDecimal getReturnTaxPrice() {
        return returnTaxPrice;
    }

    public void setReturnTaxPrice(BigDecimal returnTaxPrice) {
        this.returnTaxPrice = returnTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-zdsstore-impl-3.0.0-20240201.025532-155-sources.jar: com/ejianc/business/zdsstore/bean/ReturnGoodsDetailEntity.java <==
package com.ejianc.business.zdsstore.bean;

import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 材料退货明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbusiness_return_goods_detail")
public class ReturnGoodsDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="store_id")
    private Long storeId; // 仓库id
    @TableField(value="store_name")
    private String storeName; // 仓库名称
    @TableField(value="outstore_id")
    private Long outstoreId; // 主表id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value = "material_type_code")
    private String materialTypeCode; //物资分类编码
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value = "material_code")
    private String materialCode; //物资编码
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit_id")
    private Long materialUnitId; // 物资计量单位id
    @TableField(value="material_unit_name")
    private String materialUnitName; // 物资计量单位
    @TableField(value="instore_num")
    private BigDecimal instoreNum; // 入库数量
    @TableField(value="userable_num")
    private BigDecimal userableNum; // 剩余可用数量
    @TableField(value="return_num")
    private BigDecimal returnNum; // 退货数量
    @TableField(value="contract_price")
    private BigDecimal contractPrice; // 合同单价
    @TableField(value="return_price")
    private BigDecimal returnPrice; // 退货单价
    @TableField(value="return_tax_price")
    private BigDecimal returnTaxPrice; // 退货单价(含税)
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率
    @TableField(value="mny")
    private BigDecimal mny; // 金额
    @TableField(value="tax_mny")
    private BigDecimal taxMny; // 金额(含税)
    @TableField(value="tax")
    private BigDecimal tax; //税额
    @TableField(value="memo")
    private String memo; // 备注

    @TableField(value = "detail_mny_disparity")
    private BigDecimal detailMnyDisparity; //退货差额
    @TableField(value = "detail_tax_mny_disparity")
    private BigDecimal detailTaxMnyDisparity; //退货差额
    @TableField(value = "brand_id")
    private Long brandId; //品牌Id
    @TableField(value = "brand_name")
    private String brandName; //品牌名称
    @TableField(value = "product_code")
    private String productCode; //产品代码

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }

    public BigDecimal getDetailMnyDisparity() {
        return detailMnyDisparity;
    }

    public void setDetailMnyDisparity(BigDecimal detailMnyDisparity) {
        this.detailMnyDisparity = detailMnyDisparity;
    }

    public BigDecimal getDetailTaxMnyDisparity() {
        return detailTaxMnyDisparity;
    }

    public void setDetailTaxMnyDisparity(BigDecimal detailTaxMnyDisparity) {
        this.detailTaxMnyDisparity = detailTaxMnyDisparity;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public String getProductCode() {
        return productCode;
    }

    public void setProductCode(String productCode) {
        this.productCode = productCode;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }
    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }
    public Long getOutstoreId() {
        return outstoreId;
    }

    public void setOutstoreId(Long outstoreId) {
        this.outstoreId = outstoreId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public Long getMaterialUnitId() {
        return materialUnitId;
    }

    public void setMaterialUnitId(Long materialUnitId) {
        this.materialUnitId = materialUnitId;
    }
    public String getMaterialUnitName() {
        return materialUnitName;
    }

    public void setMaterialUnitName(String materialUnitName) {
        this.materialUnitName = materialUnitName;
    }
    public BigDecimal getInstoreNum() {
        return instoreNum;
    }

    public void setInstoreNum(BigDecimal instoreNum) {
        this.instoreNum = instoreNum;
    }
    public BigDecimal getUserableNum() {
        return userableNum;
    }

    public void setUserableNum(BigDecimal userableNum) {
        this.userableNum = userableNum;
    }
    public BigDecimal getReturnNum() {
        return returnNum;
    }

    public void setReturnNum(BigDecimal returnNum) {
        this.returnNum = returnNum;
    }
    public BigDecimal getContractPrice() {
        return contractPrice;
    }

    public void setContractPrice(BigDecimal contractPrice) {
        this.contractPrice = contractPrice;
    }
    public BigDecimal getReturnPrice() {
        return returnPrice;
    }

    public void setReturnPrice(BigDecimal returnPrice) {
        this.returnPrice = returnPrice;
    }
    public BigDecimal getReturnTaxPrice() {
        return returnTaxPrice;
    }

    public void setReturnTaxPrice(BigDecimal returnTaxPrice) {
        this.returnTaxPrice = returnTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
